..
    This file is part of Invenio.
    Copyright (C) 2015-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

.. _community:

Community
---------
Notes on getting involved, contributing, legal information and release notes
are here for the interested.

.. toctree::
    :maxdepth: 2
    :name: mastertoc

    contributing/index
    security-policy
    governance
    code-of-conduct
    license
    history
